function out = equation_2(delta,T)
  
  %  This function calculates the ratio of ADP/A
  %
  %  Calculations are according to Myagkov et al. 2020 (AMTD)
  %  "Evaluation of the reflectivity calibration of W-band radars based on
  %  observations in rain".
  %  Coefficients are taken from Table A2, the output correspond to Eq. 2.
  %
  %  Input parameters:
  %
  %  delta: backscattering phase shift in deg. It must be from 0 to 4.5.
  %  T: temperature in deg C. 
  %  T must be one of the following values 0, 10, 20, 30.
  %
  %  Output parameters:
  %
  %  out: ratio ADP/A in dB/km * km/dB
  %
  %  Example:
  %
  %  plot(0:0.1:4.5,equation_2(0:0.1:4.5,0))
  %  hold on
  %  plot(0:0.1:4.5,equation_2(0:0.1:4.5,10))
  %  plot(0:0.1:4.5,equation_2(0:0.1:4.5,20))
  %  plot(0:0.1:4.5,equation_2(0:0.1:4.5,30))
  %  grid on
  %  xlabel('Backscattering phase shift [^\circ]')
  %  ylabel('ADP/A [dB km^{-1} dB^{-1} km]')
  %  legend('0 ^\circ C','10 ^\circ C','20 ^\circ C','30 ^\circ C')
  %
  %  This code has been tested in Octave versions 4.4.0 and 5.1.0, 
  %  and in Matlab r2014b
  %
  %  Author:  Dr. Alexander Myagkov, Radiometer Physics GmbH
  %  Contact: alexander.myagkov@radiometer-physics.de
  
  if length(T) > 1 | length(T) == 0
    error('Parameter T must be a scalar')
  end
  
  switch T
    
    case 0
    
      b1 = -8.2211*10^(-3);
      b2 = 1.2129;
      b3 = 0.53705;
      b4 = 10.658;
      b5 = 7.5556*10^(-2);
      b6 = 1.2967;
      b7 = 1.4359;
      b8 = -0.13421;
      b9 = -0.19654;
      b10 = -8.8884; 
  
    case 10
      
      b1 = -4.5595*10^(-2);
      b2 = -0.77215;
      b3 = 0.86755;
      b4 = -3.3521*10^(-2);
      b5 = 0.87027;
      b6 = -1.2025;
      b7 = -0.21182;
      b8 = -1.2072*10^(-2);
      b9 = 3.9624*10^(-2);
      b10 = 1.6606*10^(-2);
      
    case 20
      
      b1 = 1.794*10^(-3);
      b2 = 3.348;
      b3 = -2.9703;
      b4 = 0.48458;
      b5 = 0.49678;
      b6 = 1.9062;
      b7 = 4.9308*10^(-2);
      b8 = 0.23934;
      b9 = -2.1627;
      b10 = -0.41128;
      
    case 30
      
      b1 = 1.9692;
      b2 = -2.1116;
      b3 = 0.87381;
      b4 = 1.9814;
      b5 = 2.105;
      b6 = -0.87086;
      b7 = -3.6404;
      b8 = -1.1534*10^(-3);
      b9 = -3.2384*10^(-2);
      b10 = -0.1098;
      
    otherwise
      
      error('Temperature must be one of the following values 0,10,20,30 deg C.')
      
  end
  
  if length(delta) == 0
    error('delta is not specified')
  end
  
  if sum(delta < 0 | delta > 4.5) > 0
    error('Delta must be in the range from 0 to 4.5 deg.')
  end  
  
  x1 = b2.*delta + b3;
  x2 = b5.*delta + b6;
  x3 = b8.*delta + b9;
  
  f1 = 2./(1+exp(-2*x1))-1;
  f2 = 2./(1+exp(-2*x2))-1;
  f3 = 2./(1+exp(-2*x3))-1;
  
  out = b1.*f1 + b4.*f2 + b7.*f3 + b10;
  
end